@@ -4,12 +4,19 @@ package Test::Class::Moose;
 
 use 5.10.0;
 
-our $VERSION = '0.66';
+our $VERSION = '0.72';
 
 use Moose 2.0000;
 use Carp;
 use namespace::autoclean;
+use Import::Into;
 use Sub::Attribute;
+use Test::Most ();
+
+# We don't use anything from these two modules, but we want to specify a
+# specific prereq version.
+use Test2 1.302015      ();
+use Test::More 1.302015 ();
 
 use Test::Class::Moose::AttributeRegistry;
 use Test::Class::Moose::Config;
@@ -118,6 +125,13 @@ has 'test_class' => (
     default  => sub { ref $_[0] },
 );
 
+has 'test_instance_name' => (
+    is       => 'rw',
+    writer   => '_set_test_instance_name',
+    isa      => 'Str',
+    init_arg => undef,
+);
+
 has 'test_skip' => (
     is      => 'rw',
     isa     => 'Str',
@@ -130,23 +144,24 @@ has '_config_p' => (
 );
 
 sub import {
-    my ( $class, %arg_for ) = @_;
+    my $class = shift;
+    my %args  = @_;
+
     my $caller = caller;
 
-    my $preamble = <<"END";
-package $caller;
-use Moose;
-use Test::Most;
-use Sub::Attribute;
-END
+    my @imports = qw(
+      Moose
+      Sub::Attribute
+      strict
+      warnings
+    );
 
-    eval $preamble;
-    croak($@) if $@;
-    strict->import;
-    warnings->import;
-    if ( my $parent
-        = ( delete $arg_for{parent} || delete $arg_for{extends} ) )
-    {
+    push @imports, 'Test::Most'
+      unless $args{bare};
+
+    $_->import::into($caller) for @imports;
+
+    if ( my $parent = ( delete $args{parent} || delete $args{extends} ) ) {
         my @parents = 'ARRAY' eq ref $parent ? @$parent : $parent;
         $caller->meta->superclasses(@parents);
     }
@@ -193,7 +208,10 @@ sub runtests {
 sub _tcm_make_test_class_instances {
     my $test_class = shift;
 
-    return ( $test_class => $test_class->new(@_) );
+    my $instance = $test_class->new(@_);
+    $instance->_set_test_instance_name($test_class);
+
+    return $instance;
 }
 
 sub test_methods {
@@ -226,6 +244,8 @@ sub test_setup    { }
 sub test_teardown { }
 sub test_shutdown { }
 
+sub run_test_shutdown_on_skip {0}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -234,13 +254,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::Class::Moose - Serious testing for serious Perl
 
 =head1 VERSION
 
-version 0.66
+version 0.72
 
 =head1 SYNOPSIS
 
@@ -296,7 +318,7 @@ you get:
 Better docs will come later. You should already know how to use Moose and
 L<Test::Class>.
 
-=for Pod::Coverage Tags Tests runtests
+=for Pod::Coverage Tags Tests runtests run_test_shutdown_on_skip
 
 =head1 BASICS
 
@@ -417,6 +439,51 @@ List it as the C<extends> in the import list.
 
  1;
 
+=head2 Skipping Test::Most
+
+By default, when you C<use Test::Class::Moose> in your own test class, it
+exports all the subs from L<Test::Most> into your class. If you'd prefer to
+import a different set of test tools, you can pass C<< bare => 1 >> when using
+C<Test::Class::Moose>:
+
+ use Test::Class::Moose bare => 1;
+
+When you pass this, C<Test::Class::Moose> will not export L<Test::Most>'s subs
+into your class. You will have to explicitly import something like
+L<Test::More> or L<Test2::Tools::Compare> in order to actually perform tests.
+
+=head2 Custom Test Toolkits
+
+If you'd like to provide a custom set of test modules to all of your test
+classes, this is easily done with L<Import::Into>:
+
+  package MM::Test::Class::Moose;
+
+  use strict;
+  use warnings;
+  use namespace::autoclean ();
+
+  use Import::Into;
+  use Test::Class::Moose ();
+  use Test::Fatal;
+  use Test::More;
+
+  sub import {
+      my @imports = qw(
+        Test::Class::Moose
+        namespace::autoclean
+        Test::Fatal
+        Test::More
+      );
+
+      my $caller_level = 1;
+      $_->import::into($caller_level) for @imports;
+  }
+
+You could also create a kit in a separate module like C<My::Test::Kit> using
+L<Test::Kit> and then simply export that from your C<My::Test::Class::Moose>
+module with L<Import::Into>.
+
 =head1 TEST CONTROL METHODS
 
 Do not run tests in test control methods. This will cause the test control
@@ -477,7 +544,8 @@ you're about to run, you can do this:
     $test->next::method;
  }
 
-Runs at the end of each test method.
+Runs at the end of each test method. This method is always run, even if the
+method was skipped.
 
 =head2 C<test_shutdown>
 
@@ -489,6 +557,10 @@ Runs at the end of each test method.
 
 Runs at the end of each test class.
 
+By default, this is not run if the test class is skipped entirely. You can
+override the C<run_test_shutdown_on_skip> in your class to return a true value
+in order to force this method to be run when the class is skipped.
+
 =head2 Overriding Test Control Methods
 
 To override a test control method, just remember that this is OO:
@@ -662,7 +734,7 @@ marked C<deprecated>:
         exclude_tags => 'deprecated',
     )->runtests;
 
-You can also inspect tags withing your test classes:
+You can also inspect tags within your test classes:
 
     sub test_setup {
         my $test          = shift;
@@ -854,6 +926,17 @@ for you, see L<Test::Class::Moose::Role::AutoUse> in this distribution.
 
 =head1 DEPRECATIONS
 
+=head2 Version 0.67
+
+=over 4
+
+=item * The L<Test::Class::Moose::Report> class's C<test_classes> method is un-deprecated
+
+This method now returns a list of L<Test::Class::Moose::Report::Class>
+objects. A class report contains one or more instance reports.
+
+=back
+
 =head2 Version 0.55
 
 =over 4
@@ -952,14 +1035,6 @@ You write this:
 
 =back
 
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-test-class-moose at rt.cpan.org>,
-or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Test-Class-Moose>.  I will be
-notified, and then you'll automatically be notified of progress on your bug as
-I make changes.
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
@@ -1013,6 +1088,18 @@ L<Test::Class> + L<Test::Most>.
 
 =back
 
+=head1 BUGS
+
+Please report any bugs or feature requests to C<bug-test-class-moose at rt.cpan.org>,
+or through the web interface at
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Test-Class-Moose>.  I will be
+notified, and then you'll automatically be notified of progress on your bug as
+I make changes.
+
+bugs may be submitted through L<https://github.com/test-class-moose/test-class-moose/issues>.
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHORS
 
 =over 4
@@ -1029,7 +1116,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Andy Jack Doug Bell Gregory Oschwald Jeremy Krieg Jonathan C. Otsuka Stowe Karen Etheridge mark-5 mephinet Neil Bowers Olaf Alders Paul Boyd Petrea Corneliu Stefan Steven Humphrey Stuckdownawell Tim Vroom Tom Beresford Heady Udo Oji
+=for stopwords Andy Jack Denny de la Haye Doug Bell Gregory Oschwald Jeremy Krieg Jonathan C. Otsuka Stowe Karen Etheridge mark-5 mephinet Neil Bowers Olaf Alders Paul Boyd Petrea Corneliu Stefan Steven Humphrey Stuckdownawell Tim Vroom Tom Beresford Heady Udo Oji
 
 =over 4
 
@@ -1039,6 +1126,10 @@ Andy Jack <github@veracity.ca>
 
 =item *
 
+Denny de la Haye <denny@users.noreply.github.com>
+
+=item *
+
 Doug Bell <madcityzen@gmail.com>
 
 =item *
@@ -1111,9 +1202,9 @@ Udo Oji <Velti@signor.com>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2016 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
