@@ -4,12 +4,11 @@ package Test::Class::Moose::Config;
 
 use 5.10.0;
 
-our $VERSION = '0.66';
+our $VERSION = '0.72';
 
 use Moose;
 use Moose::Util::TypeConstraints;
 use TAP::Formatter::Color;
-use Test::Builder;
 use namespace::autoclean;
 
 subtype 'ArrayRefOfStrings', as 'Maybe[ArrayRef[Str]]';
@@ -28,12 +27,10 @@ has 'show_timing' => (
     },
 );
 
-has 'builder' => (
+has 'set_process_name' => (
     is      => 'ro',
-    isa     => 'Test::Builder',
-    default => sub {
-        Test::Builder->new;
-    },
+    isa     => 'Bool',
+    default => 0,
 );
 
 has 'statistics' => (
@@ -115,19 +112,20 @@ __PACKAGE__->meta->make_immutable;
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::Class::Moose::Config - Configuration information for Test::Class::Moose
 
 =head1 VERSION
 
-version 0.66
+version 0.72
 
 =head1 SYNOPSIS
 
  my $tc_config = Test::Class::Moose::Config->new({
      show_timing => 1,
-     builder     => Test::Builder->new,
      statistics  => 1,
      randomize   => 0,
  });
@@ -195,11 +193,6 @@ them. For example, if your network is down:
      exclude_tags => 'network',
  });
 
-=head2 C<builder>
-
-Usually defaults to C<< Test::Builder->new >>, but you could substitute your
-own if it conforms to the interface.
-
 =head2 C<randomize>
 
 Boolean. Will run test methods of a class in a random order.
@@ -217,14 +210,6 @@ Boolean. Will run test classes in a random order.
 Returns a hash of the args used to build the configuration. Used in
 testing. You probably won't need it.
 
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-test-class-moose at rt.cpan.org>,
-or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Test-Class-Moose>.  I will be
-notified, and then you'll automatically be notified of progress on your bug as
-I make changes.
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
@@ -255,6 +240,18 @@ L<http://search.cpan.org/dist/Test-Class-Moose/>
 
 =head1 ACKNOWLEDGEMENTS
 
+=head1 BUGS
+
+Please report any bugs or feature requests to C<bug-test-class-moose at rt.cpan.org>,
+or through the web interface at
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Test-Class-Moose>.  I will be
+notified, and then you'll automatically be notified of progress on your bug as
+I make changes.
+
+bugs may be submitted through L<https://github.com/test-class-moose/test-class-moose/issues>.
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHORS
 
 =over 4
@@ -269,9 +266,9 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2016 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
