@@ -2,11 +2,15 @@ package Test::Class::Moose::Deprecated;
 
 # ABSTRACT: Managed deprecation warnings for Test::Class::Moose
 
+use strict;
+use warnings;
+use namespace::autoclean;
+
 use 5.10.0;
 
-our $VERSION = '0.66';
+our $VERSION = '0.72';
 
-use Package::DeprecationManager -deprecations => {
+use Package::DeprecationManager 0.16 -deprecations => {
     'Test::Class::Moose->runtests' => '0.55',
 };
 
@@ -16,13 +20,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::Class::Moose::Deprecated - Managed deprecation warnings for Test::Class::Moose
 
 =head1 VERSION
 
-version 0.66
+version 0.72
 
 =head1 DESCRIPTION
 
@@ -47,6 +53,12 @@ This was deprecated in version 0.55.
 
 Use L<Test::Class::Moose::Runner> to run tests instead.
 
+=head1 SUPPORT
+
+bugs may be submitted through L<https://github.com/test-class-moose/test-class-moose/issues>.
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHORS
 
 =over 4
@@ -61,9 +73,9 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2016 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
