@@ -2,9 +2,13 @@ package Test::Class::Moose::Role::HasTimeReport;
 
 # ABSTRACT: Report timing role
 
+use strict;
+use warnings;
+use namespace::autoclean;
+
 use 5.10.0;
 
-our $VERSION = '0.66';
+our $VERSION = '0.72';
 
 use Moose::Role;
 use Benchmark qw(timediff timestr :hireswallclock);
@@ -56,13 +60,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::Class::Moose::Role::HasTimeReport - Report timing role
 
 =head1 VERSION
 
-version 0.66
+version 0.72
 
 =head1 DESCRIPTION
 
@@ -82,6 +88,12 @@ Returns a L<Test::Class::Moose::Report::Time> object. This object
 represents the duration of this class or method. The duration may be "0" if
 it's an abstract class with no tests run.
 
+=head1 SUPPORT
+
+bugs may be submitted through L<https://github.com/test-class-moose/test-class-moose/issues>.
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHORS
 
 =over 4
@@ -96,9 +108,9 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2016 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
