@@ -2,9 +2,13 @@ package Test::Class::Moose::Role::ParameterizedInstances;
 
 # ABSTRACT: run tests against multiple instances of a test class
 
+use strict;
+use warnings;
+use namespace::autoclean;
+
 use 5.10.0;
 
-our $VERSION = '0.66';
+our $VERSION = '0.72';
 
 use Moose::Role;
 
@@ -15,8 +19,15 @@ sub _tcm_make_test_class_instances {
     my %base_args = @_;
 
     my %sets = $class->_constructor_parameter_sets;
-    return map { $_ => $class->new( %{ $sets{$_} }, %base_args ) }
-      keys %sets;
+
+    my @instances;
+    for my $name ( keys %sets ) {
+        my $instance = $class->new( %{ $sets{$name} }, %base_args );
+        $instance->_set_test_instance_name($name);
+        push @instances, $instance;
+    }
+
+    return @instances;
 }
 
 1;
@@ -25,13 +36,21 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::Class::Moose::Role::ParameterizedInstances - run tests against multiple instances of a test class
 
 =head1 VERSION
 
-version 0.66
+version 0.72
+
+=head1 SUPPORT
+
+bugs may be submitted through L<https://github.com/test-class-moose/test-class-moose/issues>.
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
 
 =head1 AUTHORS
 
@@ -47,9 +66,9 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2016 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
