@@ -4,7 +4,7 @@ package Test::Class::Moose::Runner;
 
 use 5.10.0;
 
-our $VERSION = '0.66';
+our $VERSION = '0.72';
 
 use Moose 2.0000;
 use Carp;
@@ -76,13 +76,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::Class::Moose::Runner - Runner for Test::Class::Moose tests
 
 =head1 VERSION
 
-version 0.66
+version 0.72
 
 =head1 SYNOPSIS
 
@@ -119,6 +121,13 @@ boost. This does mean a global state will be shared, so keep this in mind.
 Boolean. Will display verbose information on the amount of time it takes each
 test class/test method to run. Defaults to false, but see C<use_environment>.
 
+=item * C<set_process_name>
+
+Boolean. If this is true, then C<$0> will be updated to include the test
+instance name for each test instance as it is run, and then further updated as
+each test control method and test method are run, This can be helpful when
+debugging hanging tests. Defaults to false.
+
 =item * C<statistics>
 
 Boolean. Will display number of classes, test methods and tests run. Defaults
@@ -146,12 +155,6 @@ Boolean. Will run test classes in a random order. Note that if you specify an
 explicit list of classes in C<test_classes>, these classes will be run in the
 order you specify.
 
-=item * C<builder>
-
-Defaults to C<< Test::Builder->new >>. You can supply your own builder if you
-want, but it must conform to the L<Test::Builder> interface. We make no
-guarantees about which part of the interface it needs.
-
 =item * C<test_classes>
 
 Takes a class name or an array reference of class names. If it is present,
@@ -276,6 +279,12 @@ that class will be not be run in a child process. All test classes which can't
 be run in parallel are run sequentially after all parallelizable classes have
 run.
 
+=head1 SUPPORT
+
+bugs may be submitted through L<https://github.com/test-class-moose/test-class-moose/issues>.
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHORS
 
 =over 4
@@ -290,9 +299,9 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2012 - 2015 by Curtis "Ovid" Poe.
+This software is copyright (c) 2012 - 2016 by Curtis "Ovid" Poe.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
